@@ -11,7 +11,7 @@
       WITHOUT ANY WARRANTY; without even the implied warranty of
       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
       Affero General Public License for more details.
-     
+
       You should have received a copy of the GNU Affero General Public License
       along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -102,7 +102,6 @@ enum GNUNET_SCHEDULER_Reason
  */
 enum GNUNET_SCHEDULER_EventType
 {
-
   /**
    * No event (useful for timeout).
    */
@@ -137,7 +136,6 @@ enum GNUNET_SCHEDULER_EventType
    *
    */
   GNUNET_SCHEDULER_ET_NVAL = 32
-
 };
 
 
@@ -146,7 +144,6 @@ enum GNUNET_SCHEDULER_EventType
  */
 struct GNUNET_SCHEDULER_FdInfo
 {
-
   /**
    * GNUnet network socket the event is about, matches @a sock,
    * NULL if this is about a file handle or if no network
@@ -170,7 +167,6 @@ struct GNUNET_SCHEDULER_FdInfo
    * Underlying OS handle the event was about.
    */
   int sock;
-
 };
 
 
@@ -210,12 +206,9 @@ struct GNUNET_SCHEDULER_TaskContext
    * @deprecated
    */
   const struct GNUNET_NETWORK_FDSet *write_ready;
-
 };
 
 
-
-
 /**
  * Function used by event-loop implementations to signal the scheduler
  * that a particular @a task is ready due to an event specified in the
@@ -229,7 +222,7 @@ struct GNUNET_SCHEDULER_TaskContext
  */
 void
 GNUNET_SCHEDULER_task_ready (struct GNUNET_SCHEDULER_Task *task,
-			     struct GNUNET_SCHEDULER_FdInfo *fdi);
+                             struct GNUNET_SCHEDULER_FdInfo *fdi);
 
 
 /**
@@ -241,7 +234,7 @@ struct GNUNET_SCHEDULER_Handle;
 /**
  * Function called by external event loop implementations to tell the
  * scheduler to run some of the tasks that are ready. Must be called
- * only after #GNUNET_SCHEDULER_driver_init has been called and before 
+ * only after #GNUNET_SCHEDULER_driver_init has been called and before
  * #GNUNET_SCHEDULER_driver_done is called.
  * This function may return even though there are tasks left to run
  * just to give other tasks a chance as well.  If we return #GNUNET_YES,
@@ -268,14 +261,13 @@ GNUNET_SCHEDULER_do_work (struct GNUNET_SCHEDULER_Handle *sh);
  */
 struct GNUNET_SCHEDULER_Driver
 {
-
   /**
    * Closure to pass to the functions in this struct.
    */
   void *cls;
 
   /**
-   * Add a @a task to be run if the conditions specified in the 
+   * Add a @a task to be run if the conditions specified in the
    * et field of the given @a fdi are satisfied. The et field will
    * be cleared after this call and the driver is expected to set
    * the type of the actual event before passing @a fdi to
@@ -289,7 +281,7 @@ struct GNUNET_SCHEDULER_Driver
    */
   int
   (*add)(void *cls,
-	 struct GNUNET_SCHEDULER_Task *task,
+         struct GNUNET_SCHEDULER_Task *task,
          struct GNUNET_SCHEDULER_FdInfo *fdi);
 
   /**
@@ -304,7 +296,7 @@ struct GNUNET_SCHEDULER_Driver
    */
   int
   (*del)(void *cls,
-	 struct GNUNET_SCHEDULER_Task *task);
+         struct GNUNET_SCHEDULER_Task *task);
 
   /**
    * Set time at which we definitively want to get a wakeup call.
@@ -314,8 +306,7 @@ struct GNUNET_SCHEDULER_Driver
    */
   void
   (*set_wakeup)(void *cls,
-		struct GNUNET_TIME_Absolute dt);
-
+                struct GNUNET_TIME_Absolute dt);
 };
 
 
@@ -332,7 +323,7 @@ typedef void
  * Function called by external event loop implementations to initialize
  * the scheduler. An external implementation has to provide @a driver
  * which contains callbacks for the scheduler (see definition of struct
- * #GNUNET_SCHEDULER_Driver). The callbacks are used to instruct the 
+ * #GNUNET_SCHEDULER_Driver). The callbacks are used to instruct the
  * external implementation to watch for events. If it detects any of
  * those events it is expected to call #GNUNET_SCHEDULER_do_work to let
  * the scheduler handle it. If an event is related to a specific task
@@ -341,11 +332,11 @@ typedef void
  * before by calling #GNUNET_SCHEDULER_task_ready.
  *
  * This function has to be called before any tasks are scheduled and
- * before GNUNET_SCHEDULER_do_work is called for the first time. It 
+ * before GNUNET_SCHEDULER_do_work is called for the first time. It
  * allocates resources that have to be freed again by calling
  * #GNUNET_SCHEDULER_driver_done.
  *
- * This function installs the same signal handlers as 
+ * This function installs the same signal handlers as
  * #GNUNET_SCHEDULER_run. This means SIGTERM (and other similar signals)
  * will induce a call to #GNUNET_SCHEDULER_shutdown during the next
  * call to #GNUNET_SCHEDULER_do_work. As a result, SIGTERM causes all
@@ -368,7 +359,7 @@ GNUNET_SCHEDULER_driver_init (const struct GNUNET_SCHEDULER_Driver *driver);
  * by external event loop implementations after the scheduler has
  * shut down. This is the case if both of the following conditions
  * are met:
- * 
+ *
  * - all tasks the scheduler has added through the driver's add
  *   callback have been removed again through the driver's del
  *   callback
@@ -506,10 +497,13 @@ GNUNET_SCHEDULER_cancel (struct GNUNET_SCHEDULER_Task *task);
  * @param priority priority to use for the task
  */
 void
-GNUNET_SCHEDULER_add_with_reason_and_priority (GNUNET_SCHEDULER_TaskCallback task,
+GNUNET_SCHEDULER_add_with_reason_and_priority (GNUNET_SCHEDULER_TaskCallback
+                                               task,
                                                void *task_cls,
-                                               enum GNUNET_SCHEDULER_Reason reason,
-                                               enum GNUNET_SCHEDULER_Priority priority);
+                                               enum GNUNET_SCHEDULER_Reason
+                                               reason,
+                                               enum GNUNET_SCHEDULER_Priority
+                                               priority);
 
 
 /**
@@ -559,7 +553,7 @@ GNUNET_SCHEDULER_add_now (GNUNET_SCHEDULER_TaskCallback task,
  */
 struct GNUNET_SCHEDULER_Task *
 GNUNET_SCHEDULER_add_shutdown (GNUNET_SCHEDULER_TaskCallback task,
-			       void *task_cls);
+                               void *task_cls);
 
 
 /**
@@ -629,8 +623,9 @@ GNUNET_SCHEDULER_add_at (struct GNUNET_TIME_Absolute at,
  */
 struct GNUNET_SCHEDULER_Task *
 GNUNET_SCHEDULER_add_delayed_with_priority (struct GNUNET_TIME_Relative delay,
-					    enum GNUNET_SCHEDULER_Priority priority,
-					    GNUNET_SCHEDULER_TaskCallback task,
+                                            enum GNUNET_SCHEDULER_Priority
+                                            priority,
+                                            GNUNET_SCHEDULER_TaskCallback task,
                                             void *task_cls);
 
 
@@ -703,9 +698,10 @@ GNUNET_SCHEDULER_add_read_net (struct GNUNET_TIME_Relative delay,
  */
 struct GNUNET_SCHEDULER_Task *
 GNUNET_SCHEDULER_add_read_net_with_priority (struct GNUNET_TIME_Relative delay,
-					     enum GNUNET_SCHEDULER_Priority priority,
-					     struct GNUNET_NETWORK_Handle *rfd,
-					     GNUNET_SCHEDULER_TaskCallback task,
+                                             enum GNUNET_SCHEDULER_Priority
+                                             priority,
+                                             struct GNUNET_NETWORK_Handle *rfd,
+                                             GNUNET_SCHEDULER_TaskCallback task,
                                              void *task_cls);
 
 
@@ -761,13 +757,13 @@ GNUNET_SCHEDULER_add_write_net (struct GNUNET_TIME_Relative delay,
  *         only valid until "task" is started!
  */
 struct GNUNET_SCHEDULER_Task *
-GNUNET_SCHEDULER_add_net_with_priority  (struct GNUNET_TIME_Relative delay,
-                                         enum GNUNET_SCHEDULER_Priority priority,
-                                         struct GNUNET_NETWORK_Handle *fd,
-                                         int on_read,
-                                         int on_write,
-                                         GNUNET_SCHEDULER_TaskCallback task,
-                                         void *task_cls);
+GNUNET_SCHEDULER_add_net_with_priority (struct GNUNET_TIME_Relative delay,
+                                        enum GNUNET_SCHEDULER_Priority priority,
+                                        struct GNUNET_NETWORK_Handle *fd,
+                                        int on_read,
+                                        int on_write,
+                                        GNUNET_SCHEDULER_TaskCallback task,
+                                        void *task_cls);
 
 
 /**
@@ -849,9 +845,12 @@ GNUNET_SCHEDULER_add_write_file (struct GNUNET_TIME_Relative delay,
  */
 struct GNUNET_SCHEDULER_Task *
 GNUNET_SCHEDULER_add_file_with_priority (struct GNUNET_TIME_Relative delay,
-                                         enum GNUNET_SCHEDULER_Priority priority,
-                                         const struct GNUNET_DISK_FileHandle *fd,
-                                         int on_read, int on_write,
+                                         enum GNUNET_SCHEDULER_Priority
+                                         priority,
+                                         const struct
+                                         GNUNET_DISK_FileHandle *fd,
+                                         int on_read,
+                                         int on_write,
                                          GNUNET_SCHEDULER_TaskCallback task,
                                          void *task_cls);
 
@@ -906,7 +905,6 @@ GNUNET_SCHEDULER_set_select (GNUNET_SCHEDULER_select new_select,
                              void *new_select_cls);
 
 
-
 /**
  * Change the async scope for the currently executing task and (transitively)
  * for all tasks scheduled by the current task after calling this function.
@@ -923,7 +921,6 @@ void
 GNUNET_SCHEDULER_begin_async_scope (struct GNUNET_AsyncScopeId *aid);
 
 
-
 #if 0                           /* keep Emacsens' auto-indent happy */
 {
 #endif
